@@ -7,7 +7,7 @@
 *
 * Original Author : Andreas Ericsson <ae@op5.se>
 *
-* Last Modified: $Date: 2006/10/24 21:54:06 $
+* Last Modified: $Date: 2007/01/20 06:27:17 $
 *
 * Description:
 *
@@ -38,14 +38,14 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
-* $Id: check_icmp.c,v 1.8 2006/10/24 21:54:06 opensides Exp $
+* $Id: check_icmp.c,v 1.9 2007/01/20 06:27:17 dermoth Exp $
 * 
 *****************************************************************************/
 
 /* progname may change */
 /* char *progname = "check_icmp"; */
 char *progname;
-const char *revision = "$Revision: 1.8 $";
+const char *revision = "$Revision: 1.9 $";
 const char *copyright = "2005-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -1201,7 +1201,7 @@ print_help(void)
   printf ("%0.3fms,%u%%)\n", (float)warn.rta / 1000 , warn.pl / 1000);
   printf (" %s\n", "-c");
   printf ("    %s", _("critical threshold (currently "));
-  printf ("%0.3fms,%u%%)\n", (float)crit.rta), crit.pl;
+  printf ("%0.3fms,%u%%)\n", (float)crit.rta, crit.pl);
   printf (" %s\n", "-n");
   printf ("    %s", _("number of packets to send (currently "));
   printf ("%u)\n",packets);
