@@ -5,7 +5,7 @@
 * License: GPL
 * Copyright (c) 1999-2006 nagios-plugins team
 *
-* Last Modified: $Date: 2006/10/26 20:51:24 $
+* Last Modified: $Date: 2007/01/29 14:14:05 $
 *
 * Description:
 *
@@ -27,18 +27,21 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
-* $Id: check_disk.c,v 1.79 2006/10/26 20:51:24 tonvoon Exp $
+* $Id: check_disk.c,v 1.84 2007/01/29 14:14:05 dermoth Exp $
 * 
 *****************************************************************************/
 
 const char *progname = "check_disk";
 const char *program_name = "check_disk";  /* Required for coreutils libs */
-const char *revision = "$Revision: 1.79 $";
+const char *revision = "$Revision: 1.84 $";
 const char *copyright = "1999-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
 
 #include "common.h"
+#ifdef HAVE_SYS_STAT_H
+# include <sys/stat.h>
+#endif
 #if HAVE_INTTYPES_H
 # include <inttypes.h>
 #endif
@@ -143,6 +146,8 @@ char *warn_usedspace_percent = NULL;
 char *crit_usedspace_percent = NULL;
 char *warn_usedinodes_percent = NULL;
 char *crit_usedinodes_percent = NULL;
+char *warn_freeinodes_percent = NULL;
+char *crit_freeinodes_percent = NULL;
 
 
 int
@@ -159,8 +164,8 @@ main (int argc, char **argv)
   double dfree_pct = -1, dused_pct = -1;
   double dused_units, dfree_units, dtotal_units;
   double dused_inodes_percent, dfree_inodes_percent;
-  double warning_high_tide = UINT_MAX;
-  double critical_high_tide = UINT_MAX;
+  double warning_high_tide;
+  double critical_high_tide;
   int temp_result;
 
   struct mount_entry *me;
@@ -194,6 +199,7 @@ main (int argc, char **argv)
       set_thresholds(&path->usedspace_units, warn_usedspace_units, crit_usedspace_units);
       set_thresholds(&path->usedspace_percent, warn_usedspace_percent, crit_usedspace_percent);
       set_thresholds(&path->usedinodes_percent, warn_usedinodes_percent, crit_usedinodes_percent);
+      set_thresholds(&path->freeinodes_percent, warn_freeinodes_percent, crit_freeinodes_percent);
     }
   } else {
     np_set_best_match(path_select_list, mount_list, exact_match);
@@ -258,8 +264,8 @@ main (int argc, char **argv)
       dfree_inodes_percent = 100 - dused_inodes_percent;
 
       if (verbose >= 3) {
-        printf ("For %s, used_pct=%g free_pct=%g used_units=%g free_units=%g total_units=%g used_inodes_pct=%g\n", 
-          me->me_mountdir, dused_pct, dfree_pct, dused_units, dfree_units, dtotal_units, dused_inodes_percent);
+        printf ("For %s, used_pct=%g free_pct=%g used_units=%g free_units=%g total_units=%g used_inodes_pct=%g free_inodes_pct=%g\n", 
+          me->me_mountdir, dused_pct, dfree_pct, dused_units, dfree_units, dtotal_units, dused_inodes_percent, dfree_inodes_percent);
       }
 
       /* Threshold comparisons */
@@ -284,12 +290,21 @@ main (int argc, char **argv)
       if (verbose >=3) printf("Usedinodes_percent result=%d\n", temp_result);
       disk_result = max_state( disk_result, temp_result );
 
+      temp_result = get_status(dfree_inodes_percent, path->freeinodes_percent);
+      if (verbose >=3) printf("Freeinodes_percent result=%d\n", temp_result);
+      disk_result = max_state( disk_result, temp_result );
+
       result = max_state(result, disk_result);
 
       /* What a mess of units. The output shows free space, the perf data shows used space. Yikes!
          Hack here. Trying to get warn/crit levels from freespace_(units|percent) for perf
          data. Assumption that start=0. Roll on new syntax...
       */
+
+      /* *_high_tide must be reinitialized at each run */
+      warning_high_tide = UINT_MAX;
+      critical_high_tide = UINT_MAX;
+
       if (path->freespace_units->warning != NULL) {
         warning_high_tide = dtotal_units - path->freespace_units->warning->end;
       }
@@ -306,8 +321,8 @@ main (int argc, char **argv)
       asprintf (&perf, "%s %s", perf,
                 perfdata ((!strcmp(me->me_mountdir, "none") || display_mntp) ? me->me_devname : me->me_mountdir,
                           dused_units, units,
-			  TRUE, warning_high_tide,
-			  TRUE, critical_high_tide,
+			  (warning_high_tide != UINT_MAX ? TRUE : FALSE), warning_high_tide,
+			  (critical_high_tide != UINT_MAX ? TRUE : FALSE), critical_high_tide,
 			  TRUE, 0,
 			  TRUE, dtotal_units));
 
@@ -474,10 +489,18 @@ process_arguments (int argc, char **argv)
       break;
 
     case 'W':			/* warning inode threshold */
-      warn_usedinodes_percent = optarg;
+      if (*optarg == '@') {
+        warn_freeinodes_percent = optarg;
+      } else {
+        asprintf(&warn_freeinodes_percent, "@%s", optarg);
+      }
       break;
     case 'K':			/* critical inode threshold */
-      crit_usedinodes_percent = optarg;
+      if (*optarg == '@') {
+        crit_freeinodes_percent = optarg;
+      } else {
+        asprintf(&crit_freeinodes_percent, "@%s", optarg);
+      }
       break;
     case 'u':
       if (units)
@@ -522,7 +545,7 @@ process_arguments (int argc, char **argv)
       if (! (warn_freespace_units || crit_freespace_units || warn_freespace_percent || 
              crit_freespace_percent || warn_usedspace_units || crit_usedspace_units ||
              warn_usedspace_percent || crit_usedspace_percent || warn_usedinodes_percent ||
-             crit_usedinodes_percent)) {
+             crit_usedinodes_percent || warn_freeinodes_percent || crit_freeinodes_percent )) {
         die (STATE_UNKNOWN, "DISK %s: %s", _("UNKNOWN"), _("Must set a threshold value before using -p\n"));
       }
       se = np_add_parameter(&path_select_list, optarg);
@@ -531,6 +554,7 @@ process_arguments (int argc, char **argv)
       set_thresholds(&se->usedspace_units, warn_usedspace_units, crit_usedspace_units);
       set_thresholds(&se->usedspace_percent, warn_usedspace_percent, crit_usedspace_percent);
       set_thresholds(&se->usedinodes_percent, warn_usedinodes_percent, crit_usedinodes_percent);
+      set_thresholds(&se->freeinodes_percent, warn_freeinodes_percent, crit_freeinodes_percent);
       break;
     case 'x':                 /* exclude path or partition */
       np_add_name(&dp_exclude_list, optarg);
@@ -564,6 +588,8 @@ process_arguments (int argc, char **argv)
       crit_usedspace_percent = NULL;
       warn_usedinodes_percent = NULL;
       crit_usedinodes_percent = NULL;
+      warn_freeinodes_percent = NULL;
+      crit_freeinodes_percent = NULL;
       break;
     case 'V':                 /* version */
       print_revision (progname, revision);
@@ -591,6 +617,7 @@ process_arguments (int argc, char **argv)
     set_thresholds(&se->usedspace_units, warn_usedspace_units, crit_usedspace_units);
     set_thresholds(&se->usedspace_percent, warn_usedspace_percent, crit_usedspace_percent);
     set_thresholds(&se->usedinodes_percent, warn_usedinodes_percent, crit_usedinodes_percent);
+    set_thresholds(&se->freeinodes_percent, warn_freeinodes_percent, crit_freeinodes_percent);
   }
 
   if (units == NULL) {
