@@ -5,7 +5,7 @@
 * License: GPL
 * Copyright (c) 1999-2006 nagios-plugins team
 *
-* Last Modified: $Date: 2006/10/20 07:39:35 $
+* Last Modified: $Date: 2007/01/28 21:46:40 $
 *
 * Description:
 *
@@ -31,12 +31,12 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
- $Id: check_mrtg.c,v 1.28 2006/10/20 07:39:35 opensides Exp $
+ $Id: check_mrtg.c,v 1.29 2007/01/28 21:46:40 hweiss Exp $
  
 ******************************************************************************/
 
 const char *progname = "check_mrtg";
-const char *revision =  "$Revision: 1.28 $";
+const char *revision =  "$Revision: 1.29 $";
 const char *copyright = "1999-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -243,7 +243,7 @@ process_arguments (int argc, char **argv)
 			print_help ();
 			exit (STATE_OK);
 		case '?':									/* help */
-			usage2 (_("Unknown argument"), optarg);
+			usage5 ();
 		}
 	}
 
