@@ -7,7 +7,7 @@
 *  Copyright (c) 1999-2006 nagios-plugins team
 *  Copyright (c) 2000 Karl DeBisschop (kdebisschop@users.sourceforge.net)
 *
-* Last Modified: $Date: 2006/10/19 00:25:16 $
+* Last Modified: $Date: 2007/01/28 21:46:40 $
 *
 * Description:
 *
@@ -32,12 +32,12 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
-* $Id: check_mysql.c,v 1.33 2006/10/19 00:25:16 opensides Exp $
+* $Id: check_mysql.c,v 1.34 2007/01/28 21:46:40 hweiss Exp $
 *
 ******************************************************************************/
 
 const char *progname = "check_mysql";
-const char *revision = "$Revision: 1.33 $";
+const char *revision = "$Revision: 1.34 $";
 const char *copyright = "1999-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -308,7 +308,7 @@ process_arguments (int argc, char **argv)
 			verbose++;
 			break;
 		case '?':									/* help */
-			usage2 (_("Unknown argument"), optarg);
+			usage5 ();
 		}
 	}
 
