@@ -5,7 +5,7 @@
 * License: GPL
 * Copyright (c) 1999-2006 nagios-plugins team
 *
-* Last Modified: $Date: 2006/10/19 00:25:16 $
+* Last Modified: $Date: 2007/01/28 21:46:40 $
 *
 * Description:
 *
@@ -33,12 +33,12 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
- $Id: check_nagios.c,v 1.31 2006/10/19 00:25:16 opensides Exp $
+ $Id: check_nagios.c,v 1.32 2007/01/28 21:46:40 hweiss Exp $
  
 ******************************************************************************/
 
 const char *progname = "check_nagios";
-const char *revision = "$Revision: 1.31 $";
+const char *revision = "$Revision: 1.32 $";
 const char *copyright = "1999-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -258,7 +258,7 @@ process_arguments (int argc, char **argv)
 			verbose++;
 			break;
 		default:									/* print short usage_va statement if args not parsable */
-			usage_va(_("Unknown argument - %s"), optarg);
+			usage5();
 		}
 	}
 
