@@ -5,7 +5,7 @@
 * License: GPL
 * Copyright (c) 1999-2006 nagios-plugins team
 *
-* Last Modified: $Date: 2006/10/19 23:53:28 $
+* Last Modified: $Date: 2007/01/28 21:46:40 $
 *
 * Description:
 *
@@ -30,12 +30,12 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
-* $Id: check_radius.c,v 1.23 2006/10/19 23:53:28 opensides Exp $
+* $Id: check_radius.c,v 1.25 2007/01/28 21:46:40 hweiss Exp $
 * 
 *******************************************************************************/
 
 const char *progname = "check_radius";
-const char *revision = "$Revision: 1.23 $";
+const char *revision = "$Revision: 1.25 $";
 const char *copyright = "2000-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -139,6 +139,7 @@ main (int argc, char **argv)
 
 	service = PW_AUTHENTICATE_ONLY;
 
+	memset (&data, 0, sizeof(data));
 	if (!(rc_avpair_add (&data.send_pairs, PW_SERVICE_TYPE, &service, 0) &&
 				rc_avpair_add (&data.send_pairs, PW_USER_NAME, username, 0) &&
 				rc_avpair_add (&data.send_pairs, PW_USER_PASSWORD, password, 0) &&
@@ -234,7 +235,7 @@ process_arguments (int argc, char **argv)
 
 		switch (c) {
 		case '?':									/* print short usage statement if args not parsable */
-			usage2 (_("Unknown argument"), optarg);
+			usage5 ();
 		case 'h':									/* help */
 			print_help ();
 			exit (OK);
