@@ -5,7 +5,7 @@
 * License: GPL
 * Copyright (c) 1999-2006 nagios-plugins team
 *
-* Last Modified: $Date: 2006/10/19 23:53:28 $
+* Last Modified: $Date: 2007/01/28 21:46:40 $
 *
 * Description:
 *
@@ -31,12 +31,12 @@
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
-* $Id: check_smtp.c,v 1.54 2006/10/19 23:53:28 opensides Exp $
+* $Id: check_smtp.c,v 1.56 2007/01/28 21:46:40 hweiss Exp $
 * 
 ******************************************************************************/
 
 const char *progname = "check_smtp";
-const char *revision = "$Revision: 1.54 $";
+const char *revision = "$Revision: 1.56 $";
 const char *copyright = "2000-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -171,7 +171,6 @@ main (int argc, char **argv)
 	char *helocmd = NULL;
 	char *error_msg = NULL;
 	struct timeval tv;
-	struct hostent *hp;
 
 	setlocale (LC_ALL, "");
 	bindtextdomain (PACKAGE, LOCALEDIR);
@@ -191,9 +190,6 @@ main (int argc, char **argv)
 			printf(_("gethostname() failed!\n"));
 			return STATE_CRITICAL;
 		}
-		hp = gethostbyname(localhostname);
-		if(!hp) helocmd = localhostname;
-		else helocmd = hp->h_name;
 	} else {
 		helocmd = localhostname;
 	}
@@ -202,6 +198,9 @@ main (int argc, char **argv)
 	else
 		asprintf (&helocmd, "%s%s%s", SMTP_HELO, helocmd, "\r\n");
 
+	if (verbose)
+		printf("HELOCMD: %s", helocmd);
+
 	/* initialize the MAIL command with optional FROM command  */
 	asprintf (&cmd_str, "%sFROM: %s%s", mail_command, from_arg, "\r\n");
 
@@ -665,7 +664,7 @@ process_arguments (int argc, char **argv)
 			print_help ();
 			exit (STATE_OK);
 		case '?':									/* help */
-			usage2 (_("Unknown argument"), optarg);
+			usage5 ();
 		}
 	}
 
