@@ -5,7 +5,7 @@
 * License: GPL
 * Copyright (c) 2000-2006 nagios-plugins team
 *
-* Last Modified: $Date: 2006/10/19 23:53:28 $
+* Last Modified: $Date: 2007/01/28 21:46:41 $
 *
 * Description:
 *
@@ -30,12 +30,12 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
-*  $Id: check_users.c,v 1.21 2006/10/19 23:53:28 opensides Exp $
+*  $Id: check_users.c,v 1.22 2007/01/28 21:46:41 hweiss Exp $
 *
 *****************************************************************************/
 
 const char *progname = "check_users";
-const char *revision = "$Revision: 1.21 $";
+const char *revision = "$Revision: 1.22 $";
 const char *copyright = "2000-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -156,7 +156,7 @@ process_arguments (int argc, char **argv)
 
 		switch (c) {
 		case '?':									/* print short usage statement if args not parsable */
-			usage2 (_("Unknown argument"), optarg);
+			usage5 ();
 		case 'h':									/* help */
 			print_help ();
 			exit (STATE_OK);
